@@ -26,6 +26,8 @@
 #include <glib/gi18n.h>
 #include <glade/glade.h>
 
+#include <glibtop.h>
+
 #include "callbacks.h"
 #include "ping.h"
 #include "traceroute.h"
@@ -52,10 +54,10 @@ int
 main (int argc, char *argv[])
 {
 	GtkWidget *window;
-	GtkWidget *menu_quit, *menu_about, *menu_copy, *menu_clear_history;
 	GtkWidget *menu_beep;
 	GladeXML *xml;
 	GtkWidget *notebook;
+	GtkWidget *statusbar;
 	const gchar *dialog = DATADIR "gnome-nettool.glade";
 	Netinfo *pinger;
 	Netinfo *tracer;
@@ -118,6 +120,8 @@ main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
+	glibtop_init ();
+
 	if (!gtk_init_with_args (&argc, &argv, NULL, options, NULL, &error)) {
 		g_print ("%s\n\n", error->message);
 		return -1;
@@ -134,6 +138,8 @@ main (int argc, char *argv[])
 	
 	xml = glade_xml_new (dialog, "main_window", NULL);
 	window = glade_xml_get_widget (xml, "main_window");
+	statusbar = glade_xml_get_widget (xml, "statusbar");
+	gtk_statusbar_push (GTK_STATUSBAR (statusbar), 0, _("Idle"));
 
 	g_signal_connect (G_OBJECT (window), "delete-event",
 			  G_CALLBACK (gn_quit_app), NULL);
@@ -154,7 +160,7 @@ main (int argc, char *argv[])
 	if (ping_input) {
 		current_page = PING;
 		netinfo_set_host (pinger, ping_input);
-		gtk_idle_add (start_initial_process_cb, pinger);
+		g_idle_add (start_initial_process_cb, pinger);
 	}
 	if (netstat_input) {
 		current_page = NETSTAT;
@@ -167,22 +173,22 @@ main (int argc, char *argv[])
 		else if (! strcmp (netstat_input, "multicast"))
 			gtk_toggle_button_set_active
 				(GTK_TOGGLE_BUTTON (netstat->multicast), TRUE);
-		gtk_idle_add (start_initial_process_cb, netstat);
+		g_idle_add (start_initial_process_cb, netstat);
 	}
 	if (traceroute_input) {
 		current_page = TRACEROUTE;
 		netinfo_set_host (tracer, traceroute_input);
-		gtk_idle_add (start_initial_process_cb, tracer);
+		g_idle_add (start_initial_process_cb, tracer);
 	}
 	if (scan_input) {
 		current_page = PORTSCAN;
 		netinfo_set_host (scan, scan_input);
-		gtk_idle_add (start_initial_process_cb, scan);
+		g_idle_add (start_initial_process_cb, scan);
 	}
 	if (lookup_input) {
 		current_page = LOOKUP;
 		netinfo_set_host (lookup, lookup_input);
-		gtk_idle_add (start_initial_process_cb, lookup);
+		g_idle_add (start_initial_process_cb, lookup);
 	}
 	if (finger_input) {
 		gchar **split_input = NULL;
@@ -193,12 +199,12 @@ main (int argc, char *argv[])
 		if (split_input[1])
 			netinfo_set_host (finger, split_input[1]);
 		g_strfreev (split_input);
-		gtk_idle_add (start_initial_process_cb, finger);
+		g_idle_add (start_initial_process_cb, finger);
 	}
 	if (whois_input) {
 		current_page = WHOIS;
 		netinfo_set_host (whois, whois_input);
-		gtk_idle_add (start_initial_process_cb, whois);
+		g_idle_add (start_initial_process_cb, whois);
 	}
 
 	notebook = glade_xml_get_widget (xml, "notebook");
@@ -211,51 +217,23 @@ main (int argc, char *argv[])
 	g_object_set_data (G_OBJECT (notebook), "finger", finger);
 	g_object_set_data (G_OBJECT (notebook), "whois", whois);
 	
-	menu_quit = glade_xml_get_widget (xml, "m_quit");
-	
-	g_signal_connect (G_OBJECT (menu_quit), "activate",
-			  G_CALLBACK (gn_quit_app),
-			  NULL);
-
 	menu_beep = glade_xml_get_widget (xml, "m_beep");
 
 	g_signal_connect (G_OBJECT (menu_beep), "activate",
 			  G_CALLBACK (on_beep_activate),
 			  (gpointer) pinger); 
 	
-	menu_about = glade_xml_get_widget (xml, "m_about");
-
-	g_signal_connect (G_OBJECT (menu_about), "activate",
-			  G_CALLBACK (on_about_activate),
-			  (gpointer) window);
-			  	
-	menu_copy = glade_xml_get_widget (xml, "m_copy");
-
-	g_signal_connect (G_OBJECT (menu_copy), "activate",
-			  G_CALLBACK (on_copy_activate),
-			  (gpointer) notebook);
-	
-	menu_clear_history = glade_xml_get_widget (xml, "m_clear_history");
-
-	g_signal_connect (G_OBJECT (menu_clear_history), "activate",
-			  G_CALLBACK (on_clear_history_activate),
-			  (gpointer) notebook);
-			  
-	
-	
-	
 	glade_xml_signal_autoconnect (xml);
 	g_object_unref (G_OBJECT (xml));
 
-	g_signal_connect (notebook, "switch_page",
-			  G_CALLBACK (on_page_switch), NULL);
-
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), current_page);
 
 	gtk_widget_show (window);
 
 	gtk_main ();
 
+	glibtop_close ();
+
 	g_free (pinger);
 	g_free (tracer);
 	g_free (netstat);
@@ -292,7 +270,6 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
-	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -341,11 +318,6 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (pinger->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (pinger->host)));
-	tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
-			      _("Enter the network address to ping.\n"
-				"For example: www.domain.com or 192.168.2.1"),
-			      NULL);
 	
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -384,7 +356,6 @@ load_traceroute_widgets_from_xml (GladeXML * xml)
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
-	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -426,11 +397,6 @@ load_traceroute_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (tracer->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (tracer->host)));
-	tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
-			      _("Enter the network address to trace a route to.\n"
-				"For example: www.domain.com or 192.168.2.1"),
-			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -556,8 +522,7 @@ load_info_widgets_from_xml (GladeXML * xml)
 {
 	Netinfo      *info;
 	GtkTreeModel *model;
-	GtkSizeGroup *group;
-	GtkWidget    *label1, *label2;
+	GtkWidget    *label1;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -567,7 +532,6 @@ load_info_widgets_from_xml (GladeXML * xml)
 	info->running = FALSE;
 	info->combo = glade_xml_get_widget (xml, "info_combo");
 	info->ipv6_frame = glade_xml_get_widget (xml, "info_ipv6_frame");
-	info->ipv4_frame = glade_xml_get_widget (xml, "info_ipv4_frame");
 	info->progress_bar = glade_xml_get_widget (xml, "progress_bar");
 	info->page_label = glade_xml_get_widget (xml, "device");
 	info->hw_address = glade_xml_get_widget (xml, "info_hw_address");
@@ -601,13 +565,6 @@ load_info_widgets_from_xml (GladeXML * xml)
 	
 	info_list_ip_addr_add_columns (info->list_ip_addr);
 
-	label1 = glade_xml_get_widget (xml, "label_ip_address");
-	label2 = glade_xml_get_widget (xml, "label_hw_address");
-	group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (group, label1);
-	gtk_size_group_add_widget (group, label2);
-	g_object_unref (group);
-
 	label1 = glade_xml_get_widget (xml, "info_combo_label");
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label1), info->combo);
 
@@ -640,7 +597,6 @@ load_scan_widgets_from_xml (GladeXML * xml)
 	GtkWidget *label;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
-	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -680,11 +636,6 @@ load_scan_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (scan->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (scan->host)));
-	tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
-			      _("Enter the network address to scan for open ports.\n"
-				"For example: www.domain.com or 192.168.2.1"),
-			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -719,8 +670,10 @@ nettool_lookup_setup_combo_type (Netinfo *lookup)
 		N_("Internet Address"),
 		N_("Canonical Name"),
 		N_("CPU / OS Type"),
+		/* When asking for MX record in DNS context */
 		N_("Mailbox Exchange"),
 		N_("Mailbox Information"),
+		/* When asking for NS record in DNS context */
 		N_("Name Server"),
 		N_("Host name for Address"),
 		N_("Start-of-authority"),
@@ -761,7 +714,6 @@ load_lookup_widgets_from_xml (GladeXML * xml)
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
-	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -808,11 +760,6 @@ load_lookup_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (lookup->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (lookup->host)));
-	tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
-			      _("Enter the network address to lookup.\n"
-				"For example: www.domain.com or 192.168.2.1"),
-			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -846,7 +793,6 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
-	GtkTooltips *tips;
 
 	g_return_val_if_fail (xml != NULL, NULL);
 
@@ -897,10 +843,6 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->user), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (finger->user)));
-	tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
-			      _("Enter the user to finger."),
-			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -924,11 +866,6 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->host), 0);*/
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (finger->host)));
-	tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
-			      _("Enter the network address to finger that user.\n"
-			        "For example: auth.domain.com or 192.168.2.1"),
-			      NULL);
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
@@ -962,7 +899,6 @@ load_whois_widgets_from_xml (GladeXML * xml)
 	GtkEntry  *entry_host;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
-	GtkTooltips *tips;
 	PangoFontDescription *font_desc;
 	
 
@@ -1011,11 +947,6 @@ load_whois_widgets_from_xml (GladeXML * xml)
 	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (whois->host), 0);*/
 	
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (whois->host)));
-	tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
-			      _("Enter a domain address to lookup its whois information.\n"
-				"For example: www.domain.com or 192.168.2.1"),
-			      NULL);
 	
 	completion = gtk_entry_completion_new ();
 	gtk_entry_set_completion (entry_host, completion);
